/* This file is part of the KDE project
   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
   Copyright (C) 2006 Daniel Teske <teske@squorn.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef KBOOKMARKACTIONMENU_H
#define KBOOKMARKACTIONMENU_H

#include "kbookmarkactioninterface.h"
#include "kactionmenu.h"

/***
 * A wrapper around KActionMenu to provide a nice constructor for bookmark groups.
 *
 */

class KBOOKMARKS_EXPORT KBookmarkActionMenu : public KActionMenu, public KBookmarkActionInterface
{
public:
    KBookmarkActionMenu(const KBookmark &bm, QObject *parent);
    KBookmarkActionMenu(const KBookmark &bm, const QString &text, QObject *parent);
    virtual ~KBookmarkActionMenu();
};

#endif
